---
active: true

widget: portfolio

# This file represents a page section.
headless: false

# Order that this section appears on the page.
weight: 110

# title: Timeline
# subtitle: ''

content:
  # Page type to display. E.g. post, event, publication...
  page_type: animations
  # Choose how many pages you would like to display (0 = all pages)
  count: 0
  # # Filter on criteria
  # filters:
  #   author: ""
  #   category: "talks"
  #   tag: ""
  #   exclude_featured: false
  #   exclude_future: false
  #   exclude_past: false
  #   publication_type: ""

  # Choose how many pages you would like to offset by
  offset: 0
  # Page order: descending (desc) or ascending (asc) date.
  order: desc

  filter_default: 3
  filter_button:
    - name: Components
      tag: components
    - name: Layouts
      tag: layouts
    - name: Templates
      tag: templates
    - name: All
      tag: '*'



  # Choose how many pages you would like to offset by
  offset: 0
  # Page order: descending (desc) or ascending (asc) date.
  order: desc


# design:
#   # See Page Builder docs for all section customization options.
#   # Choose how many columns the section has. Valid values: '1' or '2'.
#   columns: '1'
#   # Choose a listing view
#   view: showcase
#   # For Showcase view, flip alternate rows?
#   flip_alt_rows: false

design:
  # See Page Builder docs for all section customization options.
  # Choose how many columns the section has. Valid values: '1' or '2'.
  columns: '1'
  # Choose a listing view
  view: masonry
  # For Showcase view, flip alternate rows?
  flip_alt_rows: false

---
